# mypy-boto3-glue

[![PyPI - mypy-boto3-glue](https://img.shields.io/pypi/v/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Glue 1.17.50](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/glue.html#Glue) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-glue](#mypy-boto3-glue)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Glue` service.

```bash
python -m pip install boto3-stubs[glue]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[glue]` in your environment: `python -m pip install 'boto3-stubs[glue]'`

Both type checking and auto-complete should work for `Glue` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[glue]` in your environment: `python -m pip install 'boto3-stubs[glue]'`

Both type checking and auto-complete should work for `Glue` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[glue]` in your environment: `python -m pip install 'boto3-stubs[glue]'`
- Run `mypy` as usual

Type checking should work for `Glue` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[glue]` in your environment: `python -m pip install 'boto3-stubs[glue]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Glue` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`GlueClient` provides annotations for `boto3.client("glue")`.

```python
import boto3

from mypy_boto3_glue import GlueClient

client: GlueClient = boto3.client("glue")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GlueClient = session.client("glue")
```

### Paginators annotations

`mypy_boto3_glue.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_glue import GlueClient
from mypy_boto3_glue.paginator import (
    GetClassifiersPaginator,
    GetConnectionsPaginator,
    GetCrawlerMetricsPaginator,
    GetCrawlersPaginator,
    GetDatabasesPaginator,
    GetDevEndpointsPaginator,
    GetJobRunsPaginator,
    GetJobsPaginator,
    GetPartitionIndexesPaginator,
    GetPartitionsPaginator,
    GetResourcePoliciesPaginator,
    GetSecurityConfigurationsPaginator,
    GetTableVersionsPaginator,
    GetTablesPaginator,
    GetTriggersPaginator,
    GetUserDefinedFunctionsPaginator,
    ListRegistriesPaginator,
    ListSchemaVersionsPaginator,
    ListSchemasPaginator,
)

client: GlueClient = boto3.client("glue")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_classifiers_paginator: GetClassifiersPaginator = client.get_paginator("get_classifiers")
get_connections_paginator: GetConnectionsPaginator = client.get_paginator("get_connections")
get_crawler_metrics_paginator: GetCrawlerMetricsPaginator = client.get_paginator("get_crawler_metrics")
get_crawlers_paginator: GetCrawlersPaginator = client.get_paginator("get_crawlers")
get_databases_paginator: GetDatabasesPaginator = client.get_paginator("get_databases")
get_dev_endpoints_paginator: GetDevEndpointsPaginator = client.get_paginator("get_dev_endpoints")
get_job_runs_paginator: GetJobRunsPaginator = client.get_paginator("get_job_runs")
get_jobs_paginator: GetJobsPaginator = client.get_paginator("get_jobs")
get_partition_indexes_paginator: GetPartitionIndexesPaginator = client.get_paginator("get_partition_indexes")
get_partitions_paginator: GetPartitionsPaginator = client.get_paginator("get_partitions")
get_resource_policies_paginator: GetResourcePoliciesPaginator = client.get_paginator("get_resource_policies")
get_security_configurations_paginator: GetSecurityConfigurationsPaginator = client.get_paginator("get_security_configurations")
get_table_versions_paginator: GetTableVersionsPaginator = client.get_paginator("get_table_versions")
get_tables_paginator: GetTablesPaginator = client.get_paginator("get_tables")
get_triggers_paginator: GetTriggersPaginator = client.get_paginator("get_triggers")
get_user_defined_functions_paginator: GetUserDefinedFunctionsPaginator = client.get_paginator("get_user_defined_functions")
list_registries_paginator: ListRegistriesPaginator = client.get_paginator("list_registries")
list_schema_versions_paginator: ListSchemaVersionsPaginator = client.get_paginator("list_schema_versions")
list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
```







### Typed dictionations

`mypy_boto3_glue.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_glue.type_defs import (
    ActionTypeDef,
    BackfillErrorTypeDef,
    BatchStopJobRunErrorTypeDef,
    BatchStopJobRunSuccessfulSubmissionTypeDef,
    BatchUpdatePartitionFailureEntryTypeDef,
    BinaryColumnStatisticsDataTypeDef,
    BooleanColumnStatisticsDataTypeDef,
    CatalogImportStatusTypeDef,
    CatalogTargetTypeDef,
    ClassifierTypeDef,
    CloudWatchEncryptionTypeDef,
    CodeGenEdgeTypeDef,
    CodeGenNodeArgTypeDef,
    CodeGenNodeTypeDef,
    ColumnErrorTypeDef,
    ColumnImportanceTypeDef,
    ColumnStatisticsDataTypeDef,
    ColumnStatisticsErrorTypeDef,
    ColumnStatisticsTypeDef,
    ColumnTypeDef,
    ConditionTypeDef,
    ConfusionMatrixTypeDef,
    ConnectionPasswordEncryptionTypeDef,
    ConnectionTypeDef,
    ConnectionsListTypeDef,
    CrawlTypeDef,
    CrawlerMetricsTypeDef,
    CrawlerNodeDetailsTypeDef,
    CrawlerTargetsTypeDef,
    CrawlerTypeDef,
    CsvClassifierTypeDef,
    DataCatalogEncryptionSettingsTypeDef,
    DataLakePrincipalTypeDef,
    DatabaseIdentifierTypeDef,
    DatabaseTypeDef,
    DateColumnStatisticsDataTypeDef,
    DecimalColumnStatisticsDataTypeDef,
    DecimalNumberTypeDef,
    DevEndpointTypeDef,
    DoubleColumnStatisticsDataTypeDef,
    DynamoDBTargetTypeDef,
    EdgeTypeDef,
    EncryptionAtRestTypeDef,
    EncryptionConfigurationTypeDef,
    ErrorDetailTypeDef,
    ErrorDetailsTypeDef,
    EvaluationMetricsTypeDef,
    ExecutionPropertyTypeDef,
    ExportLabelsTaskRunPropertiesTypeDef,
    FindMatchesMetricsTypeDef,
    FindMatchesParametersTypeDef,
    FindMatchesTaskRunPropertiesTypeDef,
    GluePolicyTypeDef,
    GlueTableTypeDef,
    GrokClassifierTypeDef,
    ImportLabelsTaskRunPropertiesTypeDef,
    JdbcTargetTypeDef,
    JobBookmarkEntryTypeDef,
    JobBookmarksEncryptionTypeDef,
    JobCommandTypeDef,
    JobNodeDetailsTypeDef,
    JobRunTypeDef,
    JobTypeDef,
    JsonClassifierTypeDef,
    KeySchemaElementTypeDef,
    LabelingSetGenerationTaskRunPropertiesTypeDef,
    LastCrawlInfoTypeDef,
    LineageConfigurationTypeDef,
    LongColumnStatisticsDataTypeDef,
    MLTransformTypeDef,
    MLUserDataEncryptionTypeDef,
    MappingEntryTypeDef,
    MetadataInfoTypeDef,
    MongoDBTargetTypeDef,
    NodeTypeDef,
    NotificationPropertyTypeDef,
    OrderTypeDef,
    OtherMetadataValueListItemTypeDef,
    PartitionErrorTypeDef,
    PartitionIndexDescriptorTypeDef,
    PartitionInputTypeDef,
    PartitionTypeDef,
    PartitionValueListTypeDef,
    PhysicalConnectionRequirementsTypeDef,
    PredecessorTypeDef,
    PredicateTypeDef,
    PrincipalPermissionsTypeDef,
    RecrawlPolicyTypeDef,
    RegistryListItemTypeDef,
    ResourceUriTypeDef,
    S3EncryptionTypeDef,
    S3TargetTypeDef,
    ScheduleTypeDef,
    SchemaChangePolicyTypeDef,
    SchemaColumnTypeDef,
    SchemaIdTypeDef,
    SchemaListItemTypeDef,
    SchemaReferenceTypeDef,
    SchemaVersionErrorItemTypeDef,
    SchemaVersionListItemTypeDef,
    SecurityConfigurationTypeDef,
    SerDeInfoTypeDef,
    SkewedInfoTypeDef,
    StorageDescriptorTypeDef,
    StringColumnStatisticsDataTypeDef,
    TableErrorTypeDef,
    TableIdentifierTypeDef,
    TableTypeDef,
    TableVersionErrorTypeDef,
    TableVersionTypeDef,
    TaskRunPropertiesTypeDef,
    TaskRunTypeDef,
    TransformEncryptionTypeDef,
    TransformParametersTypeDef,
    TriggerNodeDetailsTypeDef,
    TriggerTypeDef,
    UserDefinedFunctionTypeDef,
    WorkflowGraphTypeDef,
    WorkflowRunStatisticsTypeDef,
    WorkflowRunTypeDef,
    WorkflowTypeDef,
    XMLClassifierTypeDef,
    BatchCreatePartitionResponseTypeDef,
    BatchDeleteConnectionResponseTypeDef,
    BatchDeletePartitionResponseTypeDef,
    BatchDeleteTableResponseTypeDef,
    BatchDeleteTableVersionResponseTypeDef,
    BatchGetCrawlersResponseTypeDef,
    BatchGetDevEndpointsResponseTypeDef,
    BatchGetJobsResponseTypeDef,
    BatchGetPartitionResponseTypeDef,
    BatchGetTriggersResponseTypeDef,
    BatchGetWorkflowsResponseTypeDef,
    BatchStopJobRunResponseTypeDef,
    BatchUpdatePartitionRequestEntryTypeDef,
    BatchUpdatePartitionResponseTypeDef,
    CancelMLTaskRunResponseTypeDef,
    CatalogEntryTypeDef,
    CheckSchemaVersionValidityResponseTypeDef,
    ConnectionInputTypeDef,
    CreateCsvClassifierRequestTypeDef,
    CreateDevEndpointResponseTypeDef,
    CreateGrokClassifierRequestTypeDef,
    CreateJobResponseTypeDef,
    CreateJsonClassifierRequestTypeDef,
    CreateMLTransformResponseTypeDef,
    CreateRegistryResponseTypeDef,
    CreateSchemaResponseTypeDef,
    CreateScriptResponseTypeDef,
    CreateSecurityConfigurationResponseTypeDef,
    CreateTriggerResponseTypeDef,
    CreateWorkflowResponseTypeDef,
    CreateXMLClassifierRequestTypeDef,
    DatabaseInputTypeDef,
    DeleteJobResponseTypeDef,
    DeleteMLTransformResponseTypeDef,
    DeleteRegistryResponseTypeDef,
    DeleteSchemaResponseTypeDef,
    DeleteSchemaVersionsResponseTypeDef,
    DeleteTriggerResponseTypeDef,
    DeleteWorkflowResponseTypeDef,
    DevEndpointCustomLibrariesTypeDef,
    GetCatalogImportStatusResponseTypeDef,
    GetClassifierResponseTypeDef,
    GetClassifiersResponseTypeDef,
    GetColumnStatisticsForPartitionResponseTypeDef,
    GetColumnStatisticsForTableResponseTypeDef,
    GetConnectionResponseTypeDef,
    GetConnectionsFilterTypeDef,
    GetConnectionsResponseTypeDef,
    GetCrawlerMetricsResponseTypeDef,
    GetCrawlerResponseTypeDef,
    GetCrawlersResponseTypeDef,
    GetDataCatalogEncryptionSettingsResponseTypeDef,
    GetDatabaseResponseTypeDef,
    GetDatabasesResponseTypeDef,
    GetDataflowGraphResponseTypeDef,
    GetDevEndpointResponseTypeDef,
    GetDevEndpointsResponseTypeDef,
    GetJobBookmarkResponseTypeDef,
    GetJobResponseTypeDef,
    GetJobRunResponseTypeDef,
    GetJobRunsResponseTypeDef,
    GetJobsResponseTypeDef,
    GetMLTaskRunResponseTypeDef,
    GetMLTaskRunsResponseTypeDef,
    GetMLTransformResponseTypeDef,
    GetMLTransformsResponseTypeDef,
    GetMappingResponseTypeDef,
    GetPartitionIndexesResponseTypeDef,
    GetPartitionResponseTypeDef,
    GetPartitionsResponseTypeDef,
    GetPlanResponseTypeDef,
    GetRegistryResponseTypeDef,
    GetResourcePoliciesResponseTypeDef,
    GetResourcePolicyResponseTypeDef,
    GetSchemaByDefinitionResponseTypeDef,
    GetSchemaResponseTypeDef,
    GetSchemaVersionResponseTypeDef,
    GetSchemaVersionsDiffResponseTypeDef,
    GetSecurityConfigurationResponseTypeDef,
    GetSecurityConfigurationsResponseTypeDef,
    GetTableResponseTypeDef,
    GetTableVersionResponseTypeDef,
    GetTableVersionsResponseTypeDef,
    GetTablesResponseTypeDef,
    GetTagsResponseTypeDef,
    GetTriggerResponseTypeDef,
    GetTriggersResponseTypeDef,
    GetUserDefinedFunctionResponseTypeDef,
    GetUserDefinedFunctionsResponseTypeDef,
    GetWorkflowResponseTypeDef,
    GetWorkflowRunPropertiesResponseTypeDef,
    GetWorkflowRunResponseTypeDef,
    GetWorkflowRunsResponseTypeDef,
    JobUpdateTypeDef,
    ListCrawlersResponseTypeDef,
    ListDevEndpointsResponseTypeDef,
    ListJobsResponseTypeDef,
    ListMLTransformsResponseTypeDef,
    ListRegistriesResponseTypeDef,
    ListSchemaVersionsResponseTypeDef,
    ListSchemasResponseTypeDef,
    ListTriggersResponseTypeDef,
    ListWorkflowsResponseTypeDef,
    LocationTypeDef,
    MetadataKeyValuePairTypeDef,
    PaginatorConfigTypeDef,
    PartitionIndexTypeDef,
    PropertyPredicateTypeDef,
    PutResourcePolicyResponseTypeDef,
    PutSchemaVersionMetadataResponseTypeDef,
    QuerySchemaVersionMetadataResponseTypeDef,
    RegisterSchemaVersionResponseTypeDef,
    RegistryIdTypeDef,
    RemoveSchemaVersionMetadataResponseTypeDef,
    ResetJobBookmarkResponseTypeDef,
    ResumeWorkflowRunResponseTypeDef,
    SchemaVersionNumberTypeDef,
    SearchTablesResponseTypeDef,
    SegmentTypeDef,
    SortCriterionTypeDef,
    StartExportLabelsTaskRunResponseTypeDef,
    StartImportLabelsTaskRunResponseTypeDef,
    StartJobRunResponseTypeDef,
    StartMLEvaluationTaskRunResponseTypeDef,
    StartMLLabelingSetGenerationTaskRunResponseTypeDef,
    StartTriggerResponseTypeDef,
    StartWorkflowRunResponseTypeDef,
    StopTriggerResponseTypeDef,
    TableInputTypeDef,
    TaskRunFilterCriteriaTypeDef,
    TaskRunSortCriteriaTypeDef,
    TransformFilterCriteriaTypeDef,
    TransformSortCriteriaTypeDef,
    TriggerUpdateTypeDef,
    UpdateColumnStatisticsForPartitionResponseTypeDef,
    UpdateColumnStatisticsForTableResponseTypeDef,
    UpdateCsvClassifierRequestTypeDef,
    UpdateGrokClassifierRequestTypeDef,
    UpdateJobResponseTypeDef,
    UpdateJsonClassifierRequestTypeDef,
    UpdateMLTransformResponseTypeDef,
    UpdateRegistryResponseTypeDef,
    UpdateSchemaResponseTypeDef,
    UpdateTriggerResponseTypeDef,
    UpdateWorkflowResponseTypeDef,
    UpdateXMLClassifierRequestTypeDef,
    UserDefinedFunctionInputTypeDef,
)

def get_structure() -> ActionTypeDef:
    return {
      ...
    }
```
